% -- BPAM_DS_mod.m
function [data, ac, signal, DS_signal] = TX_BPAM_DS(...
                    nBits, Ns, ...
                    fs, Tf, Np, Nh, ...
                    Tm, tau, powdBm)
% INPUT:    
%       nBits       bitstream length                        []  
%       Ns          channel coder rep factor                [] 
%       fs          sampling frequency                      [Hz]
%       Tf          frame size                              [s]
%       Np          code length                             []
%       Nh          code max value                          []
%       Tm          time-duration of gaussian IR            [s]
%       tau         gaussian shape par                      [s]
%       powdBm      avg power to be tx                      [dBm]
%
% OUTPUT:   data, DS code, tx signal, DS sequence

data = binary_source(nBits);
rep_data = channel_coder(Ns, data);
a_rep_data = b2a(rep_data); % Binary To Antipodal conversion

% Direct-Sequence code as a special case of Time-Hopping code
c = TH_code_generator(2, Np);
ac = b2a(c); % Antipodal code

[PAM_DS_seq, DS_seq] = PAM_DS_mod(a_rep_data, fs, Tf, ac);
p = gaussian_wf(fs, Tm, tau, 2);
signal = conv(PAM_DS_seq, p);
signal = signal * sqrt(10^(powdBm/10) * 1e-3) * sqrt(Tf);
DS_signal = conv(DS_seq, p);
DS_signal = DS_signal * sqrt(10^(powdBm/10) * 1e-3) *sqrt(Tf);

% Time axis
dt = 1/fs;
nSmpFrame = ceil(Tf / dt );
nSmp = length(rep_data) * nSmpFrame;
t = 0:dt:nSmp*dt-dt;

% Graphics
figure()
stem1=stem(t*1e9, PAM_DS_seq); grid;
title('Coded signal');
hold on;
stem2=stem(t*1e9, DS_seq);
xlabel('Time (nanoseconds)');
legend('DS+PAM','DS only');
hold off;
set(stem1,'LineWidth',3);
set(stem2,'LineStyle','--','Color',[1 0.25 0.5]);

figure()
plot(t*1e9, signal(1:length(t))); grid;
title('TX signal');
xlabel('Time (nanoseconds)');
hold on;
plot(t*1e9, DS_signal(1:length(t)),...
    'LineStyle','--','Color',[1 0.25 0.5]);
legend('DS+PAM','DS only');
hold off;
